<?php
/**
 * Guto Lite functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Guto Lite
 * @since 1.2.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Define Constants
 */
define('GUTO_LITE_THEME', 'Starter Websites WordPress Theme');
define('GUTO_LITE_VERSION', '1.0');
define('GUTO_LITE_THEMEROOT', get_template_directory_uri());
define('GUTO_LITE_THEMEROOT_DIR', get_parent_theme_file_path());
define('GUTO_LITE_IMAGES', GUTO_LITE_THEMEROOT . '/assets/img');
define('GUTO_LITE_IMAGES_DIR', GUTO_LITE_THEMEROOT_DIR . '/assets/img');
define('GUTO_LITE_IMAGES_URI', GUTO_LITE_THEMEROOT . '/assets/img');
define('GUTO_LITE_CSS', GUTO_LITE_THEMEROOT . '/assets/css');
define('GUTO_LITE_CSS_DIR', GUTO_LITE_THEMEROOT_DIR . '/assets/css');
define('GUTO_LITE_SCRIPTS', GUTO_LITE_THEMEROOT . '/assets/js');
define('GUTO_LITE_SCRIPTS_DIR', GUTO_LITE_THEMEROOT_DIR . '/assets/js');
define('GUTO_LITE_PHPSCRIPTS', GUTO_LITE_THEMEROOT . '/assets/php');
define('GUTO_LITE_PHPSCRIPTS_DIR', GUTO_LITE_THEMEROOT_DIR . '/assets/php');
define('GUTO_LITE_INC', GUTO_LITE_THEMEROOT_DIR . '/inc');
define('GUTO_LITE_CUSTOMIZER_DIR', GUTO_LITE_INC . '/customizer/');
define('GUTO_LITE_PLUGINS_DIR', GUTO_LITE_INC . '/includes/plugins');


/**
 * Set up theme default and register various supported features.
 */
if (!function_exists('guto_lite_setup')) {

    function guto_lite_setup()
    {
        /**
         * Make the theme available for translation.
         */
        load_theme_textdomain( 'guto-lite', get_template_directory() . '/languages' );
		$locale		 = get_locale();
		$locale_file = get_template_directory() . "/languages/$locale.php";

		if ( is_readable( $locale_file ) ) {
			require_once( $locale_file );
		}

        /**
         * Add support for post formats.
         */
        add_theme_support('post-formats', array('standard'));

        /**
         * Add support for automatic feed links.
         */
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('woocommerce');
        add_theme_support('title-tag');

        /**
         * Add support for LearnPress
         */
        add_filter( 'learn-press/override-templates', function(){ return true; } );

        /**
         * Add support for post thumbnails.
         */
        add_theme_support('post-thumbnails');

        /**
         * Add custom image size
         */
		add_image_size( 'guto_lite_post_thumb', 542, 542, true );
		add_image_size( 'guto_lite_single_post_thumb', 790, 450, true );
		add_image_size( 'guto_lite_thumb_size', 790, 450, true );
        add_image_size( 'guto_lite_dm_thumb_size', 750, 500, true );
        add_image_size( 'guto_lite_thumb_size_550', 550, 550, true );

        add_image_size( 'guto_lite_banner_thumb_size', 1500, 800, true );
        add_image_size( 'guto_lite_fls_thumb_size_640*500', 640, 500, true );
        add_image_size( 'guto_lite_fls_thumb_size', 550, 500, true );
        add_image_size( 'guto_lite_fls_550*700', 550, 700, true );
        add_image_size( 'guto_lite_fls_550*450', 550, 450, true );
        add_image_size( 'guto_lite_fls_550*400', 550, 400, true );
        add_image_size( 'guto_lite_fls_thumb_640*710', 640, 710, true );
        add_image_size( 'guto_lite_fls_thumb_size_1920*900', 1920, 900, true );
        add_image_size( 'guto_lite_fls_640*370', 640, 370, true );
        add_image_size( 'guto_lite_single_post_thumb_1000*600', 1000, 600, true );
        add_image_size( 'guto_lite_ls_post_thumb', 500, 280, true );
        
        if ( class_exists( 'LearnPress' ) ):
            add_image_size( 'guto_banner_course_size', 720, 680, true );
            add_image_size( 'guto_oe_blog_thumb_size', 720, 780, true );
            add_image_size( 'guto_course_size_775_500', 775, 580, true );
        endif;

        /**
         * Register nav menus.
         */
        register_nav_menus(
            array(
                'primary'   => esc_html__('Primary Menu', 'guto-lite'),
                'footer'    => esc_html__('Footer Menu', 'guto-lite'),
            )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ));

        // Set up the WordPress core custom background feature.
		$args = array(
            'default-color' => 'fff',
            'default-image' => '',
        );
        add_theme_support( 'custom-background', $args );


        // Set up the WordPress core custom header feature.
        add_theme_support( 'custom-header' );

        /*
        * Enable support for wide alignment class for Gutenberg blocks.
        */
        add_theme_support( 'align-wide' );

        /**
         * Registers an editor stylesheet for the theme.
         */
        add_editor_style( 'custom-editor-style.css' );
    }

    add_action('after_setup_theme', 'guto_lite_setup');
}

// Default main menu
function default_main_menu(){
    echo '<ul class="navbar-nav">';
    
    if(is_user_logged_in()) {
        echo '<li class="nav-item"><a class="nav-link" href="'.esc_url(home_url()).'/wp-admin/nav-menus.php">'.esc_html('Create a menu', "guto-lite").'</a></li>';
    }
    
    else {
        echo '<li class="nav-item"><a class="nav-link" href="'.esc_url(home_url()).'">'.esc_html('Home', "guto-lite").'</a></li>';
    }

    echo '</ul>';
}

// Include necessary files
include_once get_template_directory() . '/inc/init.php';

// Post content limit
function guto_read_more($limit) {
    $post_content = explode(' ' , get_the_content());
    $less_content = array_slice($post_content, 0, $limit);
    echo implode(' ', $less_content);
}

add_action( 'admin_menu', 'guto_lite_remove_theme_settings', 999 );
function guto_lite_remove_theme_settings() {
    remove_submenu_page( 'themes.php', 'fw-settings' );
}

// Block Patterns.
require get_template_directory() . '/inc/block-patterns.php';

// Block Styles.
require get_template_directory() . '/inc/block-styles.php';

add_theme_support( "wp-block-styles" );
add_theme_support( "responsive-embeds" );
add_theme_support( "custom-logo" );
