<?php
/**
 * Template for displaying template of login form.
 *
 * This template can be overridden by copying it to guto-lite/learnpress/global/form-login.php.
 *
 * @author  ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

if( $guto_lite_current_demo == 'motivational-speaker' ) :
    $guto_login_form = 'ms-login-form';
elseif( $guto_lite_current_demo == 'life-coaching' ) :
    $guto_login_form = 'lc-login-form';
endif;

if( $guto_lite_current_demo == 'motivational-speaker' || $guto_lite_current_demo == 'life-coaching' ) : ?>
<div class="col-lg-6 col-md-12">
    <div class="<?php echo esc_attr( $guto_login_form ); ?> learn-press-form">

        <h2><?php echo esc_html_x( 'Login', 'login-heading', 'guto-lite' ); ?></h2>

        <?php do_action( 'learn-press/before-form-login' ); ?>

        <form name="learn-press-login" method="post" action="">

            <?php do_action( 'learn-press/before-form-login-fields' ); ?>

                <div class="form-group">
                    <label for="username"><?php esc_html_e( 'Username or email', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input type="text" name="username" class="form-control" id="username" placeholder="<?php esc_attr_e( 'Email or username', 'guto-lite' ); ?>" autocomplete="username" />
                </div>
                <div class="form-group">
                    <label for="password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input type="password" name="password" class="form-control"  id="password" placeholder="<?php esc_attr_e( 'Password', 'guto-lite' ); ?>" autocomplete="current-password" />
                </div>

            <?php do_action( 'learn-press/after-form-login-fields' ); ?>

            <div class="row align-items-center">
                <div class="col-lg-6 col-md-6 col-sm-6 remember-me-wrap">
                    <div class="form-check">
                        <input class="form-check-input" type="checkbox" name="rememberme"/>
                        <label class="form-check-label"><?php esc_html_e( 'Remember me', 'guto-lite' ); ?>
                        </label>
                    </div>
                </div>
                <div class="col-lg-6 col-md-6 col-sm-6 lost-your-password-wrap">
                    <a class="lost-your-password" href="<?php echo wp_lostpassword_url(); ?>"><?php esc_html_e( 'Lost your password?', 'guto-lite' ); ?></a>
                </div>
            </div>
            <input type="hidden" name="learn-press-login-nonce" value="<?php echo wp_create_nonce( 'learn-press-login' ); ?>">
            <button type="submit"><?php esc_html_e( 'Login', 'guto-lite' ); ?></button>
        </form>

        <?php do_action( 'learn-press/after-form-login' ); ?>

    </div>
</div>
<?php else : ?>
<div class="col-lg-6">
    <div class="learn-press-form-login learn-press-form">

        <h3><?php echo esc_html_x( 'Login', 'login-heading', 'guto-lite' ); ?></h3>

        <?php do_action( 'learn-press/before-form-login' ); ?>

        <form name="learn-press-login" method="post" action="">

            <?php do_action( 'learn-press/before-form-login-fields' ); ?>

            <ul class="form-fields">
                <li class="form-field">
                    <label for="username"><?php esc_html_e( 'Username or email', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input type="text" name="username" id="username" placeholder="<?php esc_attr_e( 'Email or username', 'guto-lite' ); ?>" autocomplete="username" />
                </li>
                <li class="form-field">
                    <label for="password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input type="password" name="password" id="password" placeholder="<?php esc_attr_e( 'Password', 'guto-lite' ); ?>" autocomplete="current-password" />
                </li>
            </ul>

            <?php do_action( 'learn-press/after-form-login-fields' ); ?>
            <p>
                <label>
                    <input type="checkbox" name="rememberme"/>
                    <?php esc_html_e( 'Remember me', 'guto-lite' ); ?>
                </label>
            </p>
            <p>
                <input type="hidden" name="learn-press-login-nonce" value="<?php echo wp_create_nonce( 'learn-press-login' ); ?>">
                <button type="submit"><?php esc_html_e( 'Login', 'guto-lite' ); ?></button>
            </p>
            <p>
                <a href="<?php echo wp_lostpassword_url(); ?>"><?php esc_html_e( 'Lost your password?', 'guto-lite' ); ?></a>
            </p>
        </form>

        <?php do_action( 'learn-press/after-form-login' ); ?>

    </div>
</div>
<?php endif;
