<?php
/**
 * The template for displaying all single Recipe page.
 * @package Guto Lite
 * @since 1.2.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

get_header();

    get_template_part( 'template-parts/header/content', 'recipes-header' ); 
    
    if (is_active_sidebar('recipe-sidebar') ):
        $sidebar_class = 'col-lg-8 col-md-12';
    else:
        $sidebar_class = 'col-lg-8 col-md-12 offset-lg-2';
    endif;

    $by_text     = guto_lite_option('by_text');
    $read_text   = guto_lite_option('rb_read_text');
    $share_text  = guto_lite_option('share_text');
    $prev_text   = guto_lite_option('prev_text');
    $next_text   = guto_lite_option('next_text');

    $is_social_share        = guto_lite_option( 'enable_recipe_share' );
    $is_related             = guto_lite_option( 'enable_recipe_rel_post' );
    $related_recipe_title   = guto_lite_option( 'related_recipe_title' );
    $related_post_count     = guto_lite_option( 'related_recipe_post' );
    $related_excerpt        = guto_lite_option( 'related_excerpt' );
    $rel_read_text          = guto_lite_option('related_read_text');
    ?>

    <?php guto_lite_primary_content_top(); ?>

        <div class="rb-recipes-details-area ptb-100">
            <div class="container">
                <div class="row">
                    <?php while (have_posts()) : the_post();

                        $terms = get_the_terms( get_the_ID() , 'recipe_cat' );
                    ?>
                        <div class="<?php echo esc_attr( $sidebar_class ); ?>">
                            <div class="rb-recipes-details-desc">
                                <div class="article-recipes-title">
                                    <h3><?php the_title(); ?></h3>

                                    <ul class="tag-list">
                                        <li>
                                            <i class="bx bx-time"></i>
                                            <?php echo esc_html(guto_lite_reading_time()) ?>
                                            <?php echo esc_html( $read_text ); ?>
                                        </li>

                                        <?php if( !empty( $terms ) ) : ?>
                                            <li>
                                                <i class="bx bx-tag"></i>
                                                <?php echo esc_html( $terms[0]->name ); ?>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                </div>

                                <div class="article-recipes-img">
                                    <?php if(has_post_thumbnail()) { ?>
                                        <img src="<?php the_post_thumbnail_url('full') ?>" alt="<?php the_title_attribute(); ?>">
                                    <?php } ?>
                                </div>

                                <div class="article-recipes-social">
                                
                                    <span>
                                        <?php echo esc_html( $by_text ); ?>
                                        <a href="<?php echo get_author_posts_url(get_the_author_meta('ID')); ?>"> <?php echo esc_html( get_the_author() ); ?></a>
                                    </span>

                                    <?php if( $is_social_share == true ):
							            $share_url      = get_the_permalink();
							            $share_title    = get_the_title();
							            $share_desc     = get_the_excerpt();
							        ?>
                                        <ul class="social-list">
                                            <?php if( !empty( $share_text) ) : ?>
                                                <li>
                                                    <span>  <?php echo esc_html( $share_text ); ?></span>
                                                </li>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_fb') == true ): ?>
                                                <li><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url($share_url); ?>" onclick="window.open(this.href, 'facebook-share','width=580,height=296'); return false;" class="facebook" target="_blank"><i class="bx bxl-facebook"></i></a></li>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_tw') == true ): ?>
                                                <li><a href="https://twitter.com/share?text=<?php echo urlencode($share_title); ?>&url=<?php echo esc_url($share_url); ?>" class="twitter" target="_blank"><i class="bx bxl-twitter"></i></a></li>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_ld') == true ): ?>
                                                <li><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo esc_url($share_url); ?>&amp;title=<?php echo urlencode($share_title); ?>&amp;summary=&amp;source=<?php bloginfo('name'); ?>" onclick="window.open(this.href, 'linkedin','width=580,height=296'); return false;" class="linkedin" target="_blank"><i class="bx bxl-linkedin"></i></a></li>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_wp') == true ): ?>
                                                <?php if ( wp_is_mobile() != true ) : ?>
                                                    <li><a href="https://api.whatsapp.com/send?phone=whatsappphonenumber&text=<?php echo esc_url($share_url); ?>" data-action="share/whatsapp/share" class="whatsapp" target="_blank"><i class='bx bxl-whatsapp'></i></a></li>
                                                <?php else : ?>
                                                    <li><a href="whatsapp://send?text=<?php echo esc_url($share_url); ?>" class="whatsapp" target="_blank"><i class='bx bxl-whatsapp'></i></a></li>
                                                <?php endif; ?>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_email') == true ): ?>
                                                <li><a href="mailto:?subject=<?php echo urlencode($share_title); ?> | <?php echo urlencode($share_desc); ?>&body=<?php echo esc_url($share_url); ?>" class="email" target="_blank"><i class='bx bx-mail-send' ></i></a></li>
                                            <?php endif; ?>

                                            <?php if( guto_lite_option( 'enable_rs_cp') == true ): ?>
                                                <li><a class="copy" href="#" onclick="prompt('Press Ctrl + C, then Enter to copy to clipboard','<?php echo esc_url($share_url); ?>')"><i class='bx bxs-copy' ></i></a></li>
                                            <?php endif; ?>

                                        </ul>
                                    <?php endif; ?>

                                </div>

                                <?php the_content(); ?>


                                <div class="article-navigation">
                                    <div class="navigation-links">
                                        <?php $prevPost = get_previous_post();
                                        if($prevPost) { ?>
                                            <div class="nav-previous">
                                                <a href="<?php echo get_permalink($prevPost->ID); ?>">
                                                    <i class='bx bx-chevron-left'></i>
                                                    <?php echo esc_html( $prev_text ); ?>
                                                </a>
                                            </div>
                                        <?php } 

                                        $nextPost = get_next_post();
                                        if($nextPost) { ?>
                                            <div class="nav-next">
                                                <a href="<?php echo get_permalink($nextPost->ID); ?>">
                                                    <?php echo esc_html( $next_text ); ?>
                                                    <i class='bx bx-chevron-right'></i>
                                                </a>
                                            </div>
                                        <?php } ?>
                                    </div>
                                </div>

                                <!-- Related Posts -->
                                <?php
                                    $cats               = get_the_terms(get_the_ID(), 'recipe_cat' );
                                    $cats_id            = wp_list_pluck($cats,'term_id' );

                                    if ( $related_post_count =='' ) {
                                        $related_post_count       = '3';
                                    }
                                    if ( $related_excerpt =='' ) {
                                        $related_excerpt       = '12';
                                    }

                                    $rel_posts = new WP_Query( array(
                                        'post_type' => 'recipes',
                                        'tax_query' => array(
                                            array(
                                                'taxonomy'    => 'recipe_cat',
                                                'field'       => 'id',
                                                'terms'       => $cats_id,
                                                'operator'    => 'IN' //Or 'AND' or 'NOT IN'
                                            )),
                                        'posts_per_page'      => $related_post_count,
                                        'ignore_sticky_posts' => 1,
                                        'orderby'             => 'rand',
                                        'post__not_in'        => array($post->ID)
                                    ));
                                ?>

                                <?php if ( $is_related & $rel_posts->have_posts() ) : ?>
                                    <div class="article-related">
                                        <?php if ( !empty( $related_recipe_title ) ) : ?>
                                            <h3><?php echo esc_html( $related_recipe_title ) ?></h3>
                                        <?php endif; ?>

                                        <div class="row">
                                            <?php while( $rel_posts->have_posts() ) : $rel_posts->the_post(); 
                                            
                                            $rel_cats = get_the_terms(get_the_ID(), 'recipe_cat' ); ?>
                                                <div class="col-lg-6 col-md-6">
                                                    <div class="rb-single-recipes">
                                                        <div class="recipes-image">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_dm_thumb_size' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                                            </a>
                                                        </div>
                    
                                                        <div class="recipes-content">
                                                            <?php if( !empty( $rel_cats ) ) : ?>
                                                                <span>
                                                                    <?php echo esc_html( $rel_cats[0]->name ); ?>
                                                                </span>
                                                            <?php endif; ?>
                                                            <h3>
                                                                <a href="<?php the_permalink(); ?>"><?php the_title() ?></a>
                                                            </h3>
                                                            <p><?php echo esc_html(wp_trim_words( get_the_excerpt(), $related_excerpt, '' )); ?></p>
                    
                                                            <ul class="recipes-list">
                                                                <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                                                <li>
                                                                    <?php echo esc_html(guto_lite_reading_time()) ?>
                                                                    <?php echo esc_html($rel_read_text); ?>
                                                                </li>
                                                                <li><?php comments_number(); ?></li>
                                                            </ul>
                                                        </div>
                                                    </div>
                                                </div>
                                            <?php endwhile;
                                                wp_reset_postdata();
                                            ?>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                <?php
								// If comments are open or we have at least one comment, load up the comment template.
                                    if ( comments_open() || get_comments_number() ) :
                                        comments_template();
                                    endif;
                                ?>
                            </div>
                        </div>
                    <?php endwhile; ?>

                    <?php if (is_active_sidebar('recipe-sidebar') ): ?>
                        <div class="col-lg-4 col-md-12">
                            <div class="widget-area">
                                <?php dynamic_sidebar('recipe-sidebar'); ?>
                            </div>
                        </div>
                    <?php endif; ?>

                </div>
            </div>
        </div>

    <?php guto_lite_primary_content_bottom(); ?>

<?php
get_footer();
