<?php
/**
 * The footer for Guto Lite Theme.
 * @package Guto Lite
 * @since 1.2.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

$footer_style 		    = guto_lite_option('footer_style');
$copyright_text 		= guto_lite_option('copyright_text');
$footer_columns	 		= guto_lite_option('footer_widget_layout');
$show_footer_top 		= guto_lite_option('show_footer_top');
$show_footer_instagram  = guto_lite_option('show_footer_instagram');
$shape_image 		    = guto_lite_option('footer_shape_image');

if ($footer_columns == 12) {
    $footer_column = 1;
} elseif ($footer_columns == 6) {
    $footer_column = 2;
} elseif ($footer_columns == 4) {
    $footer_column = 3;
} elseif ($footer_columns == 3) {
    $footer_column = 4;
}

if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')):
    $footer_class   = "footer-area";
    $footer_bottom  = "";
else:
    $footer_class   = "footer-section";
    $footer_bottom  = "mt-0";
endif;

if($footer_style == '1'):
    $footer_class .= " footer-light";
    $footer_bottom .= " footer-bottom-area";
endif;

if($footer_style == '2'):
    $footer_class .= " footer-light";
    $footer_bottom .= " footer-bottom-area bottom-footer-light";
endif;

// Digital Marketing Footer
if ( $guto_lite_current_demo == 'digital-marketing'):
    $is_newsletter    = guto_lite_option('is_newsletter');

    if ( defined( 'FW' ) ) {
        $is_newsletter	= fw_get_db_post_option( get_the_ID(), 'show_newsletter_section' );
        if(is_null($is_newsletter)):
            $is_newsletter  = guto_lite_option('is_newsletter');
        endif;
    }else{
        $is_newsletter  = guto_lite_option('is_newsletter');
    }

    if( $is_newsletter ) :
        $footer_cls    = '';
        $footer_status = true;
    else:
        $footer_cls    = 'dm-footer-spacing';
        $footer_status = false;
    endif; ?>
    <footer class="dm-footer-area <?php echo esc_attr($footer_cls); ?>">
        <?php if( $is_newsletter ) :
            if( $footer_status ) :
                get_template_part( 'template-parts/footer/footer','newsletter-dm' );
            endif;
        endif; ?>

        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
        <div class="container">
            <div class="row justify-content-center">
                <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                    <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                        <?php
                        if (is_active_sidebar('footer-widget-' . esc_html($i))):
                            dynamic_sidebar('footer-widget-' . esc_html($i));
                        endif;
                        ?>
                    </div>
                <?php endfor; ?>
            </div>
        </div>
        <?php endif; ?>

        <div class="dm-copyright-area">
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $copyright_text ) : ?>
                        <div class="col-lg-6 col-sm-6 col-md-6">
                            <p><?php echo do_shortcode( $copyright_text ); ?></p>
                        </div>
                    <?php endif; ?>

                    <div class="col-lg-6 col-sm-6 col-md-6">
                        <?php if( has_nav_menu('footer') ) :
                            wp_nav_menu(
                                array(
                                    'theme_location' 	=> 'footer',
                                    'menu'            	=> 'footer',
                                    'container'       	=> 'ul',
                                    'fallback_cb'  		=> false,
                                    'menu_class'      	=> 'menu',
                                    'depth'           	=> 1,
                                )
                            );
                        endif; ?>
                    </div>
                </div>
            </div>
        </div>

        <?php if( $shape_image ) : ?>
            <div class="dm-footer-shape"><img src="<?php echo esc_url($shape_image); ?>" alt="<?php esc_attr_e('Footer Shape', 'guto-lite'); ?>"></div>
    	<?php endif; ?>
    </footer>

<?php elseif ( $guto_lite_current_demo == 'coworking-space'): ?>
    <footer class="cws-footer-area footer-area">
        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
        <?php endif; ?>

        <div class="cws-footer-bottom-area">
            <div class="container">
                <?php if( $copyright_text ) : ?>
                    <p><?php echo do_shortcode( $copyright_text ); ?></p>
                <?php endif; ?>
            </div>
        </div>
    </footer>
<?php elseif ( $guto_lite_current_demo == 'freelancer'):
    $title_text 		    = guto_lite_option('footer_title');
    $footer_desc 		    = guto_lite_option('footer_desc');
    $footer_btn_txt 		= guto_lite_option('footer_button_text');
    $footer_btn_url 		= guto_lite_option('footer_button_url');
    $footer_img 		    = guto_lite_option('footer_image');

    if ( defined( 'FW' ) ) {
        $show_footer_top    = fw_get_db_post_option( get_the_ID(), 'fr_footer_top' );
        if(is_null($show_footer_top)):
            $show_footer_top  = guto_lite_option('show_fr_footer_top');
        endif;
    }else{
        $show_footer_top  = guto_lite_option('show_fr_footer_top');
    } ?>

    <?php if($show_footer_top): ?>
        <div class="fl-hire-me-area pt-100">
            <div class="container">
                <div class="row">
                    <div class="col-lg-6 col-md-12">
                        <div class="fl-hire-me-content">
                            <div class="content">
                                <?php if( $title_text ) : ?>
                                    <h2><?php echo esc_html( $title_text ); ?></h2>
                                <?php endif; ?>

                                <?php if( $footer_desc ) : ?>
                                    <p><?php echo esc_html( $footer_desc ); ?></p>
                                <?php endif; ?>
                                <?php if( $footer_btn_txt ) : ?>
                                    <a href="<?php echo esc_html( $footer_btn_url ); ?>" class="fl-default-btn"><i class='bx bxs-user-circle'></i> <?php echo esc_html( $footer_btn_txt ); ?></a>
                                <?php endif; ?>
                            </div>
                            <div class="social-list">

                                <?php

                                if( function_exists('guto_lite_option') ) :
                                    $social_links   = guto_lite_option('footer_social_icons');
                                else:
                                    $social_links   = '';
                                endif;
                                if( is_array( $social_links ) && ! empty( $social_links ) ) : ?>
                                    <ul class="social-links">
                                        <?php foreach ( $social_links as $item ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url($item['social_url']) ?>" target="_blank">
                                                    <?php echo esc_attr($item['social_icon']) ?>
                                                </a>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <?php if( $footer_img ): ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="fl-hire-me-image">
                                <img src="<?php echo esc_url( $footer_img ); ?>" alt="<?php esc_attr_e('Footer Image', 'guto-lite'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <footer class="fl-footer-area">
            <div class="container">
                <?php if( $copyright_text ) : ?>
                    <p><?php echo do_shortcode( $copyright_text ); ?></p>
                <?php endif; ?>
            </div>
        </footer>
    <?php else: ?>
        <footer class="fl-footer-area">
            <div class="container">
                <?php if( function_exists('guto_lite_option') ) :
                    $social_links   = guto_lite_option('footer_social_icons');
                else:
                    $social_links   = '';
                endif;
                if( is_array( $social_links ) && ! empty( $social_links ) ) : ?>
                    <ul class="social-links">
                        <?php foreach ( $social_links as $item ) : ?>
                            <li>
                                <?php echo esc_html( $show_footer_top ); ?>
                                <a href="<?php echo esc_url($item['social_url']) ?>" target="_blank">
                                    <?php echo esc_attr($item['social_icon']) ?>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                <?php endif; ?>

                <?php if( $copyright_text ) : ?>
                    <p><?php echo do_shortcode( $copyright_text ); ?></p>
                <?php endif; ?>
            </div>
        </footer>
    <?php endif; ?>

<?php elseif ( $guto_lite_current_demo == 'lifestyle-blog'):

    $logo = guto_lite_option('footer_logo');

    $title_text = guto_lite_option('footer_title');

    ?>

    <!-- Instagram -->
    <div class="fls-instagram-area">
        <div class="container">

            <?php if( $title_text ) : ?>
                <div class="fls-section-title">
                    <h2><?php echo esc_html( $title_text ); ?></h2>
                </div>
            <?php endif; ?>

            <div class="fls-instagram-slider owl-theme owl-carousel">


                <?php if( function_exists('guto_lite_option') ) :
                    $insta_images   = guto_lite_option('footer_instagram_images');
                else:
                    $insta_images  = '';
                endif;
                if( is_array( $insta_images ) && ! empty( $insta_images ) ) : ?>
                    <?php foreach ( $insta_images as $item ) :
                        ?>
                        <div class="fls-instagram-item">
                            <img src="<?php echo wp_get_attachment_url( $item['insta_images'] ); ?>" alt="<?php echo esc_attr__('user image','guto-lite'); ?>">

                            <a href="<?php echo esc_url($item['insta_url']) ?>">
                                <i class='bx bxl-instagram-alt'></i>
                            </a>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <!-- End Instagram -->

    <!-- Copyright -->
    <div class="fls-copyright-area">
        <div class="container">
            <div class="fls-copyright-content">
                <div class="row align-items-center">
                    <div class="col-lg-5 col-md-12">
                        <?php if( $copyright_text ) : ?>
                            <div class="fls-copyright-item">
                                <p><?php echo do_shortcode( $copyright_text ); ?></p>
                            </div>
                        <?php endif; ?>

                    </div>
                    <div class="col-lg-3 col-md-12">
                        <div class="fls-copyright-item">
                            <div class="text-center">
                                <a class="logo" href="<?php echo esc_url(home_url('/'));?>">
                                    <?php if(!empty($logo)): ?>
                                        <img src="<?php echo esc_url($logo);  ?>" alt="<?php echo esc_attr(get_bloginfo()); ?>">
                                    <?php else: ?>
                                        <?php echo esc_html(get_bloginfo()); ?>
                                    <?php endif ?>
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-12">
                        <div class="fls-copyright-item">
                            <?php if( function_exists('guto_lite_option') ) :
                                $social_links   = guto_lite_option('footer_social_icons');
                            else:
                                $social_links   = '';
                            endif;
                            if( is_array( $social_links ) && ! empty( $social_links ) ) : ?>
                                <ul>
                                    <?php foreach ( $social_links as $item ) : ?>
                                        <li>
                                            <a href="<?php echo esc_url($item['social_url']) ?>" target="_blank">
                                                <i class='<?php echo esc_attr($item['social_icon']) ?>'></i>
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- End Copyright -->
<?php elseif ( $guto_lite_current_demo == 'motivational-speaker'): ?>
    <?php if($show_footer_instagram == 'on' ): ?>
    <!-- Start Instagram Area -->
    <div class="ms-instagram-area">
        <?php if( function_exists('guto_lite_option') ) :
                    $footer_instagram_images   = guto_lite_option('footer_instagram_images');
                else:
                    $footer_instagram_images   = '';
                endif;
        if( is_array( $footer_instagram_images ) && ! empty( $footer_instagram_images ) ) : ?>
        <div class="row justify-content-center m-0">
            <?php foreach ( $footer_instagram_images as $item ) : ?>
                <div class="col-lg-2 col-6 col-sm-4 col-md-4 p-0">
                    <div class="single-ms-instagram-box">
                        <a href="<?php echo esc_url($item['image_url']) ?>" class="d-block" target="_blank">
                            <img src="<?php echo wp_get_attachment_url($item['instagram_image']) ?>" alt="instagram">
                        </a>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php endif; ?>
    </div>
    <!-- End Instagram Area -->
    <?php endif; ?>

    <!-- Start Footer Area -->
    <footer class="ms-footer-area">
        <div class="container">
            <?php if( $copyright_text ) : ?>
                <p><?php echo do_shortcode( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </footer>
<?php elseif ( $guto_lite_current_demo == 'life-coaching'): ?>
    <?php if($show_footer_instagram == 'on' ): ?>
    <!-- Start Instagram Area -->
    <div class="lc-instagram-area">
        <?php if( function_exists('guto_lite_option') ) :
                    $footer_instagram_images   = guto_lite_option('footer_instagram_images');
                else:
                    $footer_instagram_images   = '';
                endif;
        if( is_array( $footer_instagram_images ) && ! empty( $footer_instagram_images ) ) : ?>
        <div class="row justify-content-center m-0">
            <?php foreach ( $footer_instagram_images as $item ) : ?>
                <div class="col-lg-2 col-6 col-sm-4 col-md-4 p-0">
                    <div class="single-lc-instagram-box">
                        <a href="<?php echo esc_url($item['image_url']) ?>" class="d-block" target="_blank">
                            <img src="<?php echo wp_get_attachment_url($item['instagram_image']) ?>" alt="instagram">
                        </a>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php endif; ?>
    </div>
    <!-- End Instagram Area -->
    <?php endif; ?>

    <!-- Start Footer Area -->
    <footer class="lc-footer-area">
        <div class="container">
            <?php if( $copyright_text ) : ?>
                <p><?php echo do_shortcode( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </footer>
    <!-- End Footer Area -->
<?php elseif ( $guto_lite_current_demo == 'recipe-blog'):

    $is_instagram    = guto_lite_option('is_instagram');

    if( $is_instagram ) :
        get_template_part( 'template-parts/footer/footer','instagram-rb' );
    endif; ?>

    <!-- Start RB Footer Area -->
    <div class="rb-footer-area pt-100  <?php echo esc_attr($footer_class); ?>">
        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
        <div class="container">
            <div class="row justify-content-center">
                <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                    <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                        <?php
                        if (is_active_sidebar('footer-widget-' . esc_html($i))):
                            dynamic_sidebar('footer-widget-' . esc_html($i));
                        endif;
                        ?>
                    </div>
                <?php endfor; ?>
            </div>
        </div>
        <?php endif; ?>

        <div class="rb-copyright-area wow fadeInUp <?php echo esc_attr($footer_bottom); ?>" data-wow-delay="300ms" data-wow-duration="1500ms">
            <div class="container">
                <?php if( $copyright_text ) : ?>
                    <p><?php echo do_shortcode( $copyright_text ); ?></p>
                <?php endif; ?>
            </div>
        </div>
    </div>
<?php elseif ( $guto_lite_current_demo == 'online-health-coach') :
    $is_instagram    = guto_lite_option('is_instagram');

    if( $is_instagram ) :
        get_template_part( 'template-parts/footer/footer','instagram-ohc' );
    endif; ?>
    <div class="ohc-copyright-area">
        <div class="container">
            <?php if( $copyright_text ) : ?>
                <p><?php echo do_shortcode( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </div>
<?php elseif( $footer_style == '5' ) : ?>
    <!-- Start NM Footer Area -->
    <div class="nm-footer-area ptb-80">
        <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <!-- Start NM Copy Right Area -->
    <div class="nm-copy-right-area">
        <div class="container">
            <?php if($copyright_text ): ?>
                <p><?php echo do_shortcode( $copyright_text ); ?></p>
            <?php endif; ?>
        </div>
    </div>
<?php elseif( $footer_style == '' || $footer_style == '1' || $footer_style == '2' || $footer_style == '3' ) : ?>
    <footer class="<?php echo esc_attr($footer_class); ?>">
    	<?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
            <div class="container">
                <div class="row">
                    <?php for ($i = 1; $i <= $footer_column; $i++): ?>
                        <div class="col-lg-<?php echo esc_attr($footer_columns); ?>">
                            <?php
                            if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                dynamic_sidebar('footer-widget-' . esc_html($i));
                            endif;
                            ?>
                        </div>
                    <?php endfor; ?>
                </div>
            </div>
    	<?php endif; ?>

        <div class="<?php echo esc_attr($footer_bottom); ?>">
            <div class="container">
                <div class="row align-items-center">
                    <?php if($copyright_text ): ?>
                        <div class="col-lg-6 col-sm-6 col-md-6">
                            <p><?php echo do_shortcode( $copyright_text ); ?></p>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-6 col-sm-6 col-md-6">
                        <?php if( $footer_style == '' || $footer_style == '1' || $footer_style == '2' ) :
                            if( has_nav_menu('footer') ) :
                                wp_nav_menu(
                                    array(
                                        'theme_location' 	=> 'footer',
                                        'menu'            	=> 'footer',
                                        'container'       	=> 'ul',
                                        'fallback_cb'  		=> false,
                                        'menu_class'      	=> 'menu',
                                        'depth'           	=> 1,
                                    )
                                );
                            endif;
                        elseif( $footer_style == '3' ) :
                            if( function_exists('guto_lite_option') ) :
                                $social_links   = guto_lite_option('footer_social_links');
                            else:
                                $social_links   = '';
                            endif;
                            if( is_array( $social_links ) && ! empty( $social_links ) ) : ?>
                                <ul class="social-links">
                                    <?php foreach ( $social_links as $index => $item ) : ?>
                                        <li>
                                            <a href="<?php echo esc_url($item['social_url']) ?>" target="_blank">
                                                <i class="<?php echo esc_attr($item['social_icon']) ?>"></i>
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php endif;
                        endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php if($shape_image): ?>
            <div class="circle-map"><img src="<?php echo esc_url($shape_image); ?>" alt="<?php esc_attr_e('Circle', 'guto-lite'); ?>"></div>
    	<?php endif; ?>
    </footer>
<?php endif; ?>