<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 4.4.0
 */

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_cart' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

$cart_style = guto_lite_option( 'cart_style' );

if( $cart_style == 'style-1' ) : ?>

    <div class="cart-area">
        <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
            <div class="cart-table table-responsive">
                <?php do_action( 'woocommerce_before_cart_table' ); ?>

                <table class="shop_table cart woocommerce-cart-form__contents table table-bordered" cellspacing="0">
                    <thead>
                        <tr>
                            <th class="product-img"><?php esc_html_e( 'Product', 'guto-lite' ); ?></th>
                            <th class="product-name"><?php esc_html_e( 'Name', 'guto-lite' ); ?></th>
                            <th class="product-price"><?php esc_html_e( 'Unit Price', 'guto-lite' ); ?></th>
                            <th class="product-quantity"><?php esc_html_e( 'Quantity', 'guto-lite' ); ?></th>
                            <th class="product-subtotal"><?php esc_html_e( 'Subtotal', 'guto-lite' ); ?></th>
                            <th class="product-remove">&nbsp;</th>

                        </tr>
                    </thead>
                    <tbody>
                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                    <?php
                    foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                        $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                        $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                        if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                            $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                            ?>
                            <tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">



                                <td class="product-thumbnail">
                                <?php
                                $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                if ( ! $product_permalink ) {
                                    echo wp_kses_post($thumbnail, 'guto-lite');
                                } else {
                                    printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
                                }
                                ?>
                                </td>

                                <td class="product-name" data-title="<?php esc_attr_e( 'Product', 'guto-lite' ); ?>">
                                <?php
                                if ( ! $product_permalink ) {
                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
                                } else {
                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
                                }

                                do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                // Meta data.
                                echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

                                // Backorder notification.
                                if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'guto-lite' ) . '</p>', $product_id ) );
                                }
                                ?>
                                </td>

                                <td class="product-price" data-title="<?php esc_attr_e( 'Price', 'guto-lite' ); ?>">
                                    <?php
                                        echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
                                        ?>
                                </td>

                                <td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'guto-lite' ); ?>">
                                <?php
                                    if ( $_product->is_sold_individually() ) {
                                        $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                    } else {
                                        $product_quantity = woocommerce_quantity_input(
                                            array(
                                                'input_name'   => "cart[{$cart_item_key}][qty]",
                                                'input_value'  => $cart_item['quantity'],
                                                'max_value'    => $_product->get_max_purchase_quantity(),
                                                'min_value'    => '0',
                                                'product_name' => $_product->get_name(),
                                            ),
                                            $_product,
                                            false
                                        );
                                    }

                                    echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                    ?>
                                </td>

                                <td class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'guto-lite' ); ?>">
                                    <?php
                                        echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
                                        ?>
                                </td>

                                <td class="product-remove">
                                    <?php
                                        // @codingStandardsIgnoreLine
                                        echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                            '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="fa fa-trash"></i></a>',
                                            esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                            __( 'Remove this item', 'guto-lite' ),
                                            esc_attr( $product_id ),
                                            esc_attr( $_product->get_sku() )
                                        ), $cart_item_key );
                                    ?>
                                </td>
                            </tr>
                            <?php
                        }
                    }
                    ?>

                    <?php do_action( 'woocommerce_cart_contents' ); ?>

                        <tr>
                            <td colspan="6" class="actions">

                                <?php if ( wc_coupons_enabled() ) { ?>
                                    <div class="coupon">
                                        <label for="coupon_code"><?php esc_html_e( 'Coupon:', 'guto-lite' ); ?></label>
                                        <input type="text" name="coupon_code" class="input-text form-control" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'guto-lite' ); ?>" /> <button type="submit" class="btn btn-primary" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'guto-lite' ); ?>"><?php esc_html_e( 'Apply Coupon', 'guto-lite' ); ?></button>
                                        <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                    </div>
                                <?php } ?>

                                <button type="submit" class="btn btn-primary" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'guto-lite' ); ?>"><?php esc_html_e( 'Update Cart', 'guto-lite' ); ?></button>

                                <?php do_action( 'woocommerce_cart_actions' ); ?>

                                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
                            </td>
                        </tr>
                        <?php do_action( 'woocommerce_after_cart_contents' ); ?>
                    </tbody>
                </table>
                <?php do_action( 'woocommerce_after_cart_table' ); ?>
            </div>
        </form>
        <div class="cart-collaterals">
            <?php
                /**
                 * Cart collaterals hook.
                 *
                 * @hooked woocommerce_cross_sell_display
                 * @hooked woocommerce_cart_totals - 10
                 */
                do_action( 'woocommerce_cart_collaterals' );
            ?>
        </div>
    </div>

<?php elseif( $cart_style == 'style-2' ) : ?>
    <div class="restaurant-cart-area">
        <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
            <div class="restaurant-cart-table table-responsive">
                <?php do_action( 'woocommerce_before_cart_table' ); ?>

                <table class="table table-bordered" cellspacing="0">
                    <thead>
                        <tr>
                            <th class="product-img"><?php esc_html_e( 'Product', 'guto-lite' ); ?></th>
                            <th class="product-name"><?php esc_html_e( 'Name', 'guto-lite' ); ?></th>
                            <th class="product-price"><?php esc_html_e( 'Unit Price', 'guto-lite' ); ?></th>
                            <th class="product-quantity"><?php esc_html_e( 'Quantity', 'guto-lite' ); ?></th>
                            <th class="product-subtotal"><?php esc_html_e( 'Total', 'guto-lite' ); ?></th>
                            <th class="product-remove">&nbsp;</th>

                        </tr>
                    </thead>
                    <tbody>
                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                        <?php
                        foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                                ?>
                                <tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

                                    <td class="product-thumbnail">
                                    <?php
                                    $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                    if ( ! $product_permalink ) {
                                        echo wp_kses_post($thumbnail, 'guto-lite');
                                    } else {
                                        printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
                                    }
                                    ?>
                                    </td>

                                    <td class="product-name" data-title="<?php esc_attr_e( 'Product', 'guto-lite' ); ?>">
                                    <?php
                                    if ( ! $product_permalink ) {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', wp_kses_post($_product->get_name()), $cart_item, $cart_item_key ) . '&nbsp;' );
                                    } else {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($_product->get_name()) ), $cart_item, $cart_item_key ) );
                                    }

                                    do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                    // Meta data.
                                    echo wp_kses_post(wc_get_formatted_cart_item_data( $cart_item ));

                                    // Backorder notification.
                                    if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'guto-lite' ) . '</p>', $product_id ) );
                                    }
                                    ?>
                                    </td>

                                    <td class="product-price" data-title="<?php esc_attr_e( 'Price', 'guto-lite' ); ?>">
                                        <?php
                                            echo wp_kses_post(apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ));
                                        ?>
                                    </td>

                                    <td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'guto-lite' ); ?>">
                                    <?php
                                        if ( $_product->is_sold_individually() ) {
                                            $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                        } else {
                                            $product_quantity = woocommerce_quantity_input(
                                                array(
                                                    'input_name'   => "cart[{$cart_item_key}][qty]",
                                                    'input_value'  => $cart_item['quantity'],
                                                    'max_value'    => $_product->get_max_purchase_quantity(),
                                                    'min_value'    => '0',
                                                    'product_name' => $_product->get_name(),
                                                ),
                                                $_product,
                                                false
                                            );
                                        }

                                        echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                        ?>
                                    </td>

                                    <td class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'guto-lite' ); ?>">
                                        <?php
                                            echo wp_kses_post(apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ));
                                        ?>
                                        <?php
                                            // @codingStandardsIgnoreLine
                                            echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                                '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="bx bx-trash"></i></a>',
                                                esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                                __( 'Remove this item', 'guto-lite' ),
                                                esc_attr( $product_id ),
                                                esc_attr( $_product->get_sku() )
                                            ), $cart_item_key );
                                        ?>
                                    </td>
                                </tr>
                                <?php
                            }
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <?php do_action( 'woocommerce_cart_contents' ); ?>
                <div class="restaurant-cart-buttons">
                    <div class="row align-items-center">
                        <div class="col-lg-7 col-sm-12 col-md-7">

                            <?php if ( wc_coupons_enabled() ) { ?>
                                <div class="shopping-coupon-code">
                                    <input type="text" name="coupon_code" class="input-text form-control" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'guto-lite' ); ?>" /> <button type="submit" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'guto-lite' ); ?>"><?php esc_html_e( 'Apply Coupon', 'guto-lite' ); ?></button>
                                    <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                </div>
                            <?php } ?>
                            </div>

                            <div class="col-lg-5 col-sm-12 col-md-5 text-right">
                                <button type="submit" class="default-btn" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'guto-lite' ); ?>"><i class='bx bx-refresh'></i><?php esc_html_e( 'Update Cart', 'guto-lite' ); ?></button>
                                <?php do_action( 'woocommerce_cart_actions' ); ?>
                                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php do_action( 'woocommerce_after_cart_contents' ); ?>
            <?php do_action( 'woocommerce_after_cart_table' ); ?>
        </form>
        <div class="restaurant-cart-totals">
            <?php
                /**
                 * Cart collaterals hook.
                 *
                 * @hooked woocommerce_cross_sell_display
                 * @hooked woocommerce_cart_totals - 10
                 */
                do_action( 'woocommerce_cart_collaterals' );
            ?>
        </div>
    </div>

<?php elseif( $cart_style == 'style-ls' ) : ?>
    <div class="fls-cart-area">
        <div class="container">

            <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

                <div class="table-item">
                    <?php do_action( 'woocommerce_before_cart_table' ); ?>
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th scope="col"><?php esc_html_e( 'Product', 'guto-lite' ); ?></th>
                                <th scope="col"><?php esc_html_e( 'Name', 'guto-lite' ); ?></th>
                                <th scope="col"><?php esc_html_e( 'Price', 'guto-lite' ); ?></th>
                                <th scope="col"><?php esc_html_e( 'Quantity', 'guto-lite' ); ?></th>
                                <th scope="col"><?php esc_html_e( 'Total', 'guto-lite' ); ?></th>
                                <th scope="col"><?php esc_html_e( 'Remove', 'guto-lite' ); ?></th>
                            </tr>
                        </thead>
                        <tbody>

                            <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                            <?php
                            foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                                $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                                $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                                if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                    $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                                    ?>
                                    <tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

                                        <td class="product-thumbnail">
                                            <?php
                                                $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                                if ( ! $product_permalink ) {
                                                    echo wp_kses_post($thumbnail, 'guto-lite');
                                                } else {
                                                    printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
                                                }
                                            ?>
                                        </td>

                                        <td class="product-name" data-title="<?php esc_attr_e( 'Product', 'guto-lite' ); ?>">
                                            <?php
                                                if ( ! $product_permalink ) {
                                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', wp_kses_post($_product->get_name()), $cart_item, $cart_item_key ) . '&nbsp;' );
                                                } else {
                                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($_product->get_name()) ), $cart_item, $cart_item_key ) );
                                                }

                                                do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                                // Meta data.
                                                echo wp_kses_post(wc_get_formatted_cart_item_data( $cart_item ));

                                                // Backorder notification.
                                                if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                                    echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'guto-lite' ) . '</p>', $product_id ) );
                                                }
                                            ?>
                                        </td>

                                        <td class="product-price" data-title="<?php esc_attr_e( 'Price', 'guto-lite' ); ?>">
                                            <?php
                                                echo wp_kses_post(apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ));
                                            ?>
                                        </td>

                                        <td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'guto-lite' ); ?>">
                                            <?php
                                                if ( $_product->is_sold_individually() ) {
                                                    $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                                } else {
                                                    $product_quantity = woocommerce_quantity_input(
                                                        array(
                                                            'input_name'   => "cart[{$cart_item_key}][qty]",
                                                            'input_value'  => $cart_item['quantity'],
                                                            'max_value'    => $_product->get_max_purchase_quantity(),
                                                            'min_value'    => '0',
                                                            'product_name' => $_product->get_name(),
                                                        ),
                                                        $_product,
                                                        false
                                                    );
                                                }

                                                echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                            ?>
                                        </td>

                                        <td class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'guto-lite' ); ?>">
                                            <?php
                                                echo wp_kses_post(apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ));
                                            ?>
                                           
                                        </td>

                                        <td class="product-remove">
                                            <?php
                                                // @codingStandardsIgnoreLine
                                                echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                                    '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="bx bx-x"></i></a>',
                                                    esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                                    __( 'Remove this item', 'guto-lite' ),
                                                    esc_attr( $product_id ),
                                                    esc_attr( $_product->get_sku() )
                                                ), $cart_item_key );
                                            ?>
                                        </td>
                                    </tr>
                                    <?php
                                }
                            }
                            ?>

                        </tbody>
                    </table>
                </div>

                <?php do_action( 'woocommerce_cart_contents' ); ?>


                <div class="table-cart">
                    <ul class="align-items-center">
                        <li>
                            <div class="left">
                                <?php if ( wc_coupons_enabled() ) { ?>
                                    <div class="form">
                                        <input type="text" name="coupon_code" class="input-text form-control" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'guto-lite' ); ?>" /> <button type="submit" class="btn fls-default-btn" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'guto-lite' ); ?>"><?php esc_html_e( 'Apply Coupon', 'guto-lite' ); ?></button>
                                        <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </li>
                        <li>
                            <div class="right">
                                <button type="submit" class="fls-default-btn" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'guto-lite' ); ?>"><?php esc_html_e( 'Update Cart', 'guto-lite' ); ?></button>
                                <?php do_action( 'woocommerce_cart_actions' ); ?>
                                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
                            </div>
                        </li>
                    </ul>
                </div>

                <?php do_action( 'woocommerce_after_cart_contents' ); ?>
                <?php do_action( 'woocommerce_after_cart_table' ); ?>

            </form>

            <div class="cart-total">
                <?php
                    /**
                     * Cart collaterals hook.
                     *
                     * @hooked woocommerce_cross_sell_display
                     * @hooked woocommerce_cart_totals - 10
                     */
                    do_action( 'woocommerce_cart_collaterals' );
                ?>
            </div>

        </div>
    </div>

<?php elseif( $guto_lite_current_demo == 'life-coaching' ) : ?>
    <div class="lc-cart-area">
        <form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
            <div class="lc-cart-table table-responsive">
                <?php do_action( 'woocommerce_before_cart_table' ); ?>

                <table class="table table-bordered" cellspacing="0">
                    <thead>
                        <tr>
                            <th class="product-img"><?php esc_html_e( 'Product', 'guto-lite' ); ?></th>
                            <th class="product-name"><?php esc_html_e( 'Name', 'guto-lite' ); ?></th>
                            <th class="product-price"><?php esc_html_e( 'Unit Price', 'guto-lite' ); ?></th>
                            <th class="product-quantity"><?php esc_html_e( 'Quantity', 'guto-lite' ); ?></th>
                            <th class="product-subtotal"><?php esc_html_e( 'Total', 'guto-lite' ); ?></th>
                            <th class="product-remove">&nbsp;</th>

                        </tr>
                    </thead>
                    <tbody>
                        <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                        <?php
                        foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                                ?>
                                <tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

                                    <td class="product-thumbnail">
                                    <?php
                                    $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                    if ( ! $product_permalink ) {
                                        echo wp_kses_post($thumbnail, 'guto-lite');
                                    } else {
                                        printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
                                    }
                                    ?>
                                    </td>

                                    <td class="product-name" data-title="<?php esc_attr_e( 'Product', 'guto-lite' ); ?>">
                                    <?php
                                    if ( ! $product_permalink ) {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', wp_kses_post($_product->get_name()), $cart_item, $cart_item_key ) . '&nbsp;' );
                                    } else {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($_product->get_name()) ), $cart_item, $cart_item_key ) );
                                    }

                                    do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                    // Meta data.
                                    echo wp_kses_post(wc_get_formatted_cart_item_data( $cart_item ));

                                    // Backorder notification.
                                    if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                        echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'guto-lite' ) . '</p>', $product_id ) );
                                    }
                                    ?>
                                    </td>

                                    <td class="product-price" data-title="<?php esc_attr_e( 'Price', 'guto-lite' ); ?>">
                                        <?php
                                            echo wp_kses_post(apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ));
                                        ?>
                                    </td>

                                    <td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'guto-lite' ); ?>">
                                    <?php
                                        if ( $_product->is_sold_individually() ) {
                                            $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                        } else {
                                            $product_quantity = woocommerce_quantity_input(
                                                array(
                                                    'input_name'   => "cart[{$cart_item_key}][qty]",
                                                    'input_value'  => $cart_item['quantity'],
                                                    'max_value'    => $_product->get_max_purchase_quantity(),
                                                    'min_value'    => '0',
                                                    'product_name' => $_product->get_name(),
                                                ),
                                                $_product,
                                                false
                                            );
                                        }

                                        echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                        ?>
                                    </td>

                                    <td class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'guto-lite' ); ?>">
                                        <?php
                                            echo wp_kses_post(apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ));
                                        ?>
                                        <?php
                                            // @codingStandardsIgnoreLine
                                            echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                                '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="bx bx-trash"></i></a>',
                                                esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                                __( 'Remove this item', 'guto-lite' ),
                                                esc_attr( $product_id ),
                                                esc_attr( $_product->get_sku() )
                                            ), $cart_item_key );
                                        ?>
                                    </td>
                                </tr>
                                <?php
                            }
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <?php do_action( 'woocommerce_cart_contents' ); ?>
                <div class="lc-cart-buttons">
                    <div class="row align-items-center">
                        <div class="col-lg-7 col-sm-12 col-md-7">

                            <?php if ( wc_coupons_enabled() ) { ?>
                                <div class="shopping-coupon-code">
                                    <input type="text" name="coupon_code" class="input-text form-control" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'guto-lite' ); ?>" /> <button type="submit" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'guto-lite' ); ?>"><?php esc_html_e( 'Apply Coupon', 'guto-lite' ); ?></button>
                                    <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                </div>
                            <?php } ?>
                            </div>

                            <div class="col-lg-5 col-sm-12 col-md-5 text-end">
                                <button type="submit" class="lc-default-btn" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'guto-lite' ); ?>"><i class='bx bx-refresh'></i><?php esc_html_e( 'Update Cart', 'guto-lite' ); ?></button>
                                <?php do_action( 'woocommerce_cart_actions' ); ?>
                                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php do_action( 'woocommerce_after_cart_contents' ); ?>
            <?php do_action( 'woocommerce_after_cart_table' ); ?>
        </form>
        <div class="lc-cart-totals">
            <?php
                /**
                 * Cart collaterals hook.
                 *
                 * @hooked woocommerce_cross_sell_display
                 * @hooked woocommerce_cart_totals - 10
                 */
                do_action( 'woocommerce_cart_collaterals' );
            ?>
        </div>
    </div>

<?php endif;

do_action( 'woocommerce_after_cart' ); ?>