<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 4.3.0
 */

// phpcs:ignoreFile

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

global $product;

if ( ! comments_open() ) {
	return;
}

function get_total_reviews_count(){
    return get_comments(array(
        'status'   => 'approve',
        'post_status' => 'publish',
        'post_type'   => 'product',
        'count' => true
    ));
}

function get_products_ratings(){
    global $wpdb;
    return $wpdb->get_results("
        SELECT t.slug, tt.count
        FROM {$wpdb->prefix}terms as t
        JOIN {$wpdb->prefix}term_taxonomy as tt ON tt.term_id = t.term_id
        WHERE t.slug LIKE 'rated-%' AND tt.taxonomy LIKE 'product_visibility'
        ORDER BY t.slug
    ");
}

function products_count_by_rating_html(){
    $star = 1;
    $html = '';
    foreach( get_products_ratings() as $values ){
        $star_text = '<strong>'.$star.' '._n('Star', 'Stars', $star, 'guto-lite').'<strong>: ';
        $html .= '<li class="'.$values->slug.'">'.$star_text.$values->count.'</li>';
        $star++;
    }
    return '<ul class="products-rating">'.$html.'</ul>';
}

function products_rating_average_html(){
    $stars = 1;
    $average = 0;
    $total_count = 0;
    if( sizeof(get_products_ratings()) > 0 ) :
        foreach( get_products_ratings() as $values ){
            $average += $stars * $values->count;
            $total_count += $values->count;
            $stars++;
        }
        return '<p class="rating-average">'.round($average / $total_count, 1).' / 5 '. __('Stars average', 'guto-lite').'</p>';
    else :
        return '<p class="rating-average">'. __('No reviews yet', 'guto-lite').'</p>';
    endif;
}
$average = $product->get_average_rating();
global $comment;
$res_rating = get_total_reviews_count(); ?>

<div id="reviews" class="woocommerce-Reviews">
	<div class="products-reviews">
		<h3><?php echo esc_html__('Products Rating', 'guto-lite'); ?></h3>
		<div class="rating">
			<?php if ($average = $product->get_average_rating()) : ?>
		    <?php echo '<div class="star-rating" title="'.sprintf(__( 'Rated %s out of 5', 'guto-lite' ), $average).'"><span style="width:'.( ( $average / 5 ) * 100 ) . '%"><strong itemprop="ratingValue" class="rating">'.$average.'</strong> '.__( 'out of 5', 'guto-lite' ).'</span></div>'; ?>
		    <?php endif; ?>
	    </div>
	    <div class="rating-count">
	        <span><?php echo esc_html( $average . ' average based on ' . $res_rating . ' reviews.'); ?></span>
	    </div>
	</div>
	<div id="comments" class="products-review-comments">
		<h3 class="woocommerce-Reviews-title">
			<?php
			$count = $product->get_review_count();
			if ( $count && wc_review_ratings_enabled() ) {
				/* translators: 1: reviews count 2: product name */
				$reviews_title = sprintf( esc_html( _n( '%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'guto-lite' ) ), esc_html( $count ), '<span>' . get_the_title() . '</span>' );
				echo wp_kses_post(apply_filters( 'woocommerce_reviews_title', $reviews_title, $count, $product )); // WPCS: XSS ok.
			} else {
				esc_html_e( 'Customer Reviews', 'guto-lite' );
			}
			?>
		</h3>

		<?php if ( have_comments() ) : ?>
			<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>

			<?php
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links(
					apply_filters(
						'woocommerce_comment_pagination_args',
						array(
							'prev_text' => '&larr;',
							'next_text' => '&rarr;',
							'type'      => 'list',
						)
					)
				);
				echo '</nav>';
			endif;
			?>
		<?php else : ?>
			<p class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'guto-lite' ); ?></p>
		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>
		<div id="review_form_wrapper" class="review-form-wrapper">
			<div id="review_form">
				<?php
				$commenter = wp_get_current_commenter();

				$comment_form = array(
					/* translators: %s is product title */
					'title_reply'         => have_comments() ? __( 'Add a review', 'guto-lite' ) : sprintf( __( 'Be the first to review &ldquo;%s&rdquo;', 'guto-lite' ), get_the_title() ),
					/* translators: %s is product title */
					'title_reply_to'      => __( 'Leave a Reply to %s', 'guto-lite' ),
					'title_reply_before'  => '<h3 id="reply-title">',
					'title_reply_after'   => '</h3>',
					'comment_notes_after' => '',
					'fields'              => array(
						'author' => '<div class="row"><div class="col-lg-6 col-md-6">
                                                    <div class="form-group">' .
									'<input id="author" name="author" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="'. esc_attr__( 'Name', 'guto-lite' ) .'*" size="30" required /></div></div>',
						'email'  => '<div class="col-lg-6 col-md-6">
                                                    <div class="form-group">' .
									'<input id="email" name="email" type="email" class="form-control" value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="'. esc_attr__( 'Email', 'guto-lite' ) .'*" size="30" required /></div></div></div>',
					),
					'label_submit'        => __( 'Submit', 'guto-lite' ),
					'logged_in_as'        => '',
					'comment_field'       => '',
				);

				$account_page_url = wc_get_page_permalink( 'myaccount' );
				if ( $account_page_url ) {
					/* translators: %s opening and closing link tags respectively */
					$comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( esc_html__( 'You must be %1$slogged in%2$s to post a review.', 'guto-lite' ), '<a href="' . esc_url( $account_page_url ) . '">', '</a>' ) . '</p>';
				}

				if ( wc_review_ratings_enabled() ) {
					$comment_form['comment_field'] = '<div class="comment-form-rating"><select name="rating" id="rating" required>
						<option value="">' . esc_html__( 'Rate&hellip;', 'guto-lite' ) . '</option>
						<option value="5">' . esc_html__( 'Perfect', 'guto-lite' ) . '</option>
						<option value="4">' . esc_html__( 'Good', 'guto-lite' ) . '</option>
						<option value="3">' . esc_html__( 'Average', 'guto-lite' ) . '</option>
						<option value="2">' . esc_html__( 'Not that bad', 'guto-lite' ) . '</option>
						<option value="1">' . esc_html__( 'Very poor', 'guto-lite' ) . '</option>
					</select></div>';
				}

				$comment_form['comment_field'] .= '<p class="comment-form-comment"><textarea id="comment" class="form-control" name="comment" placeholder="'. esc_attr__( 'Your review', 'guto-lite' ) .'"  cols="45" rows="4" required></textarea></p>';

				comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>
	<?php else : ?>
		<p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'guto-lite' ); ?></p>
	<?php endif; ?>

	<div class="clear"></div>
</div>